==> haskell-diff-0.5-33.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-yETzKh0qtuDUuvJdOns8X
key:                  Diff-0.5-yETzKh0qtuDUuvJdOns8X
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  6521a82dd7a2f2b30b29d061bdab0f48
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-yETzKh0qtuDUuvJdOns8X
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-diff-0.5-34-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-8gj4s2z6jOl7FPRCGftIez
key:                  Diff-0.5-8gj4s2z6jOl7FPRCGftIez
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  6b9e8cd497d14237a76bc502591b23ab
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-8gj4s2z6jOl7FPRCGftIez
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
